==> iReport-0.5.0-src.zip: iReport-0.5.0-src/src/it/businesslogic/ireport/RoundRectangleReportElement.java <==
/*
 * RoundRectangleReportElement.java
 *
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 *
 * Created on 22 July 2004 19.20
 */
package it.businesslogic.ireport;

public class RoundRectangleReportElement extends RectangleReportElement
{
    // default radius for the rounded corner
    // this way you don't have to specify it in the element factory
    // or anywhere else
    private static int defaultRadius = 5;
    
	public RoundRectangleReportElement (int x, int y, int width, int height)
	{
        this(x,y,width,height, defaultRadius);
	}
    
	public RoundRectangleReportElement (int x, int y, int width, int height, int radius)
	{
		super(x,y,width,height);
		this.radius = radius; 
  
	}

        
}

==> iReport-1.2.7-src.zip: iReport-1.2.7-src/src/it/businesslogic/ireport/RoundRectangleReportElement.java <==
/*
 * RoundRectangleReportElement.java
 *
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 *
 * Created on 22 July 2004 19.20
 */
package it.businesslogic.ireport;

public class RoundRectangleReportElement extends RectangleReportElement
{
    // default radius for the rounded corner
    // this way you don't have to specify it in the element factory
    // or anywhere else
    private static int defaultRadius = 5;
    
	public RoundRectangleReportElement (int x, int y, int width, int height)
	{
            this(x,y,width,height, defaultRadius);
	}
    
	public RoundRectangleReportElement (int x, int y, int width, int height, int radius)
	{
		super(x,y,width,height);
                setRadius( radius ); 
        }
        
        public ReportElement cloneMe () {
            RoundRectangleReportElement newReportElement = new RoundRectangleReportElement (position.x, position.y, width, height);
            copyBaseReportElement (newReportElement, this);
            return newReportElement;
        }
}
